import sys

if sys.platform not in ["linux", "linux2"]:
    raise Exception("should be only loaded on linux")

from je_auto_control.linux_with_x11.core.utils.x11_linux_display import display


def size():
    return display.screen().width_in_pixels, display.screen().height_in_pixels



"""
keyboard tags
"""
keyboard_press_key_error_tag = "keyboard press key error"
keyboard_release_key_error_tag = "keyboard release key error"
keyboard_type_key_error_tag = "keyboard type key error"
"""
mouse tags
"""
mouse_get_position_error_tag = "mouse get position error"
mouse_set_position_error_tag = "mouse set position error"
mouse_press_mouse_error_tag = "mouse press mouse error"
mouse_release_mouse_error_tag = "mouse release key error"
mouse_click_mouse_error_tag = "mouse click mouse error"
mouse_scroll_error_tag = "mouse scroll error"
"""
screen tags
"""
screen_get_size_error_tag = "screen get size error"
"""
table tags
"""
cant_find_key_error_tag = "can't find key error"



class AutoControlException(Exception):

    def __init__(self, message="Auto control error"):
        self.message = message
        super().__init__(message)

    def __str__(self):
        return f"{self.message}"


class AutoControlKeyboardException(Exception):
    def __init__(self, message="Auto control keyboard error"):
        self.message = message
        super().__init__(message)

    def __str__(self):
        return f"{self.message}"


class AutoControlMouseException(Exception):
    def __init__(self, message="Auto control mouse error"):
        self.message = message
        super().__init__(message)

    def __str__(self):
        return f"{self.message}"


class AutoControlScreenException(Exception):
    def __init__(self, message="Auto control screen error"):
        self.message = message
        super().__init__(message)

    def __str__(self):
        return f"{self.message}"


class AutoControlCantFindKeyException(Exception):
    def __init__(self, message="Auto control can't find key error"):
        self.message = message
        super().__init__(message)

    def __str__(self):
        return f"{self.message}"


class ImageNotFoundException(Exception):

    def __init__(self, image, message="Auto control image not found error"):
        self.message = message
        self.image = image
        super().__init__(message)

    def __str__(self):
        return f"{self.message} cause by: {self.image} not found"



from PIL import ImageGrab
from je_open_cv import template_detection


def find_image(image, detect_threshold=1, draw_image=False):
    grab_image = ImageGrab.grab()
    return template_detection.find_object_cv2_with_pil(image=grab_image, template=image,
                                                       detect_threshold=detect_threshold, draw_image=draw_image)


def find_image_multi(image, detect_threshold=1, draw_image=False):
    grab_image = ImageGrab.grab()
    return template_detection.find_multi_object_cv2_with_pil(image=grab_image, template=image,
                                                             detect_threshold=detect_threshold, draw_image=draw_image)



import setuptools

with open("README.md", "r") as README:
    long_description = README.read()

setuptools.setup(
    name="je_auto_control",
    version="0.0.22",
    author="JE-Chen",
    author_email="zenmailman@gmail.com",
    description="auto control alpha 0.0.20",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/JE-Chen/Python_AutoControl",
    packages=setuptools.find_packages(),
    install_requires=["je_open_cv",
                      "pillow",
                      "numpy",
                      "pyobjc-core;platform_system=='Darwin'",
                      "pyobjc;platform_system=='Darwin'",
                      "python3-Xlib;platform_system=='Linux'"
                      ],
    classifiers=[
        "Programming Language :: Python :: 3.7",
        "Development Status :: 2 - Pre-Alpha",
        "Environment :: Win32 (MS Windows)",
        "License :: OSI Approved :: MIT License",
        "Natural Language :: Chinese (Traditional)",
        "Operating System :: Microsoft"
    ]
)

# python setup.py sdist bdist_wheel
# python -m twine upload dist/*
